@@ -1,6 +1,6 @@
 /*  $Id$
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -55,6 +55,12 @@ enum
 	SERVER_NOT_READY
 };
 
+#define TAG_HEADING "heading"
+#define TAG_ERROR "error"
+#define TAG_SUCCESS "success"
+#define TAG_LINK "link"
+#define TAG_BOLD "bold"
+#define TAG_PHONETIC "phonetic"
 
 typedef struct
 {
@@ -74,6 +80,7 @@ typedef struct
 	gchar *spell_bin;
 	gchar *spell_dictionary;
 
+	gboolean verbose_mode;
 	gboolean is_plugin;	/* specify whether the panel plugin loaded or not */
 
 	/* status values */
@@ -93,16 +100,28 @@ typedef struct
 	GtkWidget *pref_menu_item;
 	GtkWidget *main_combo;
 	GtkWidget *main_entry;
+	GtkWidget *radio_button_web;
 	GtkWidget *panel_entry;
 	GtkWidget *main_textview;
 	GtkTextBuffer *main_textbuffer;
 	GtkTextIter textiter;
 	GtkTextTag *link_tag;
 	GtkTextTag *phon_tag;
+	GtkTextTag *error_tag;
+	GtkTextTag *success_tag;
+	GtkTextMark *mark_click;
 	GdkPixbuf *icon;
 
-	GdkColor *link_color;
-	GdkColor *phon_color;
+	GdkColor *color_link;
+	GdkColor *color_phonetic;
+	GdkColor *color_correct;
+	GdkColor *color_incorrect;
+
+	/* speed reader */
+	gint speedreader_wpm;
+	gint speedreader_grouping;
+	gchar *speedreader_font;
+	gboolean speedreader_mark_paragraphs;
 } DictData;
 
 
@@ -116,5 +135,8 @@ void dict_drag_data_received(GtkWidget *widget, GdkDragContext *drag_context, gi
 
 DictData *dict_create_dictdata();
 gboolean dict_start_web_query(DictData *dd, const gchar *word);
+gchar *dict_get_web_query_uri(DictData *dd, const gchar *word);
+
+void dict_show_msgbox(DictData *dd, gint type, const gchar *text, ...) G_GNUC_PRINTF (3, 4);
 
 #endif
