@@ -1,6 +1,6 @@
 /*  $Id$
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <gtk/gtk.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <glib/gi18n.h>
 
 #include <signal.h>
 #include <sys/types.h>
@@ -190,7 +190,7 @@ static void parse_header(DictData *dd, GString *buffer, GString *target)
 		len = end - buffer->str; /* length of the phonetic string */
 
 		gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
-				buffer->str, len, "phonetic", NULL);
+				buffer->str, len, TAG_PHONETIC, NULL);
 
 		g_string_erase(buffer, 0, len + 1); /* remove already handled text */
 	}
@@ -203,9 +203,9 @@ static GtkTextTag *create_tag(DictData *dd, const gchar *link_str)
 
 	tag = gtk_text_buffer_create_tag(dd->main_textbuffer, NULL,
 		"underline", PANGO_UNDERLINE_SINGLE,
-		"foreground-gdk", dd->link_color, NULL);
+		"foreground-gdk", dd->color_link, NULL);
 
-	g_object_set_data_full(G_OBJECT(tag), "link", g_strdup(link_str), g_free);
+	g_object_set_data_full(G_OBJECT(tag), TAG_LINK, g_strdup(link_str), g_free);
 
 	return tag;
 }
@@ -313,7 +313,7 @@ static gint process_response_content(DictData *dd, gchar **lines, gint line_no,
 
 	if (g_strv_length(dict_parts) > 3)
 	{	gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
-			g_strstrip(dict_parts[3]), -1, "bold", NULL);
+			g_strstrip(dict_parts[3]), -1, TAG_BOLD, NULL);
 
 		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, " (", 2);
 		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter,
@@ -382,7 +382,7 @@ static gboolean process_server_response(DictData *dd)
 		}
 		case SERVER_NOT_READY:
 		{
-			dict_gui_status_add(dd, _("Server not ready."));
+			dict_gui_status_add(dd, _("The server is not ready."));
 			g_free(dd->query_buffer);
 			return FALSE;
 		}
@@ -410,11 +410,16 @@ static gboolean process_server_response(DictData *dd)
 
 	if (dd->query_status == NOTHING_FOUND)
 	{
-		dict_gui_status_add(dd, _("Ready."));
+		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n", 1);
+		gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
+			_("Dictionary Results:"), -1, TAG_HEADING, NULL);
 
 		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n", 1);
 		tmp = g_strdup_printf(_("No matches could be found for \"%s\"."), dd->searched_word);
 		gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, tmp, -1);
+		dict_gui_textview_apply_tag_to_word(dd->main_textbuffer, dd->searched_word, &dd->textiter,
+			TAG_ERROR, TAG_BOLD, NULL);
+		dict_gui_status_add(dd, "%s", tmp);
 		g_free(tmp);
 		g_free(dd->query_buffer);
 
@@ -422,20 +427,26 @@ static gboolean process_server_response(DictData *dd)
 		 * spell check and offer a Web search*/
 		if (NZV(dd->web_url))
 		{
+			gchar *label = _(dict_prefs_get_web_url_label(dd));
 			gchar *text = g_strdup_printf(
-				_("Do you want to search \"%s\" on the Web using "), dd->searched_word);
+				/* for translators: the first wildcard is the search term, the second wildcard
+				 * is the name of the preferred web search engine */
+				_("Search \"%s\" using \"%s\""),
+				dd->searched_word, label);
+
 			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n\n", 2);
-			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, text, -1);
-			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\"", 1);
 			gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
-				dict_prefs_get_web_url_label(dd), -1, "link", NULL);
-			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\"?", 2);
+				_("Web Search:"), -1, TAG_HEADING, NULL);
+
+			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n", 1);
+			gtk_text_buffer_insert_with_tags_by_name(dd->main_textbuffer, &dd->textiter,
+				text, -1, TAG_LINK, NULL);
 			g_free(text);
 		}
 		if (NZV(dd->spell_bin))
 		{
 			gtk_text_buffer_insert(dd->main_textbuffer, &dd->textiter, "\n", 1);
-			dict_spell_start_query(dd, dd->searched_word);
+			dict_spell_start_query(dd, dd->searched_word, FALSE);
 		}
 
 		return FALSE;
@@ -569,7 +580,7 @@ static gchar *get_answer(DictData *dd, gint fd)
 }
 
 
-static void ask_server(DictData *dd)
+static gpointer ask_server(DictData *dd)
 {
 	gint fd, i;
 	static gchar cmd[BUF_SIZE];
@@ -579,7 +590,7 @@ static void ask_server(DictData *dd)
 		dd->query_status = NO_CONNECTION;
 		g_idle_add((GSourceFunc) process_server_response, dd);
 		g_thread_exit(NULL);
-		return;
+		return NULL;
 	}
 	dd->query_is_running = TRUE;
 	dd->query_status = NO_CONNECTION;
@@ -608,6 +619,7 @@ static void ask_server(DictData *dd)
 	g_idle_add((GSourceFunc) process_server_response, dd);
 
 	g_thread_exit(NULL);
+	return NULL;
 }
 
 
@@ -670,7 +682,7 @@ void dict_dictd_get_information(GtkWidget *button, DictData *dd)
 
 	if ((fd = open_socket(server, port)) == -1)
 	{
-		xfce_err(_("Could not connect to server."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("Could not connect to server."));
 		return;
 	}
 
@@ -679,7 +691,7 @@ void dict_dictd_get_information(GtkWidget *button, DictData *dd)
 	g_free(get_answer(dd, fd));
 	if (dd->query_status != NO_ERROR)
 	{
-		xfce_err(_("Could not connect to server."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("Could not connect to server."));
 		return;
 	}
 
@@ -696,7 +708,8 @@ void dict_dictd_get_information(GtkWidget *button, DictData *dd)
 
 	if (strncmp("114", buffer, 3) != 0)
 	{
-		xfce_err(_("An error occured while querying server information."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR,
+			_("An error occured while querying server information."));
 		return;
 	}
 
@@ -761,7 +774,7 @@ void dict_dictd_get_list(GtkWidget *button, DictData *dd)
 
 	if ((fd = open_socket(server, port)) == -1)
 	{
-		xfce_err(_("Could not connect to server."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("Could not connect to server."));
 		return;
 	}
 
@@ -770,7 +783,7 @@ void dict_dictd_get_list(GtkWidget *button, DictData *dd)
 	g_free(get_answer(dd, fd));
 	if (dd->query_status != NO_ERROR)
 	{
-		xfce_err(_("Could not connect to server."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("Could not connect to server."));
 		return;
 	}
 
@@ -787,12 +800,12 @@ void dict_dictd_get_list(GtkWidget *button, DictData *dd)
 
 	if (strncmp("554", buffer, 3) == 0)
 	{
-		xfce_err(_("The server doesn't offer any databases."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("The server doesn't offer any databases."));
 		return;
 	}
 	else if (strncmp("110", buffer, 3) != 0 && strncmp("554", buffer, 3) != 0)
 	{
-		xfce_err(_("Unknown error while quering the server."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("Unknown error while quering the server."));
 		return;
 	}
 
