@@ -1,6 +1,6 @@
 /*  $Id$
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,5 +32,9 @@ void dict_gui_query_geometry(DictData *dd);
 void dict_gui_finalize(DictData *dd);
 const guint8 *dict_gui_get_icon_data(void);
 
+void dict_gui_textview_apply_tag_to_word(GtkTextBuffer *buffer, const gchar *word,
+										 GtkTextIter *pos, const gchar *first_tag,
+										 ...) G_GNUC_NULL_TERMINATED;
+
 
 #endif
