@@ -1,4 +1,4 @@
-/*  $Id: prefs.c 6505 2009-01-19 18:59:42Z enrico $
+/*  $Id$
  *
  *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
@@ -90,7 +90,7 @@ static void search_method_changed(GtkRadioButton *radiobutton, DictData *dd)
 
 void dict_prefs_dialog_response(GtkWidget *dlg, gint response, DictData *dd)
 {
-	gchar *dictionary, *search_url;
+	gchar *dictionary;
 
 	/* check some values before actually saving the settings in case we need to return to
 	 * the dialog */
@@ -98,24 +98,13 @@ void dict_prefs_dialog_response(GtkWidget *dlg, gint response, DictData *dd)
 		GTK_COMBO_BOX(g_object_get_data(G_OBJECT(dlg), "dict_combo")));
 	if (! NZV(dictionary) || dictionary[0] == '-')
 	{
-		xfce_err(_("You have chosen an invalid dictionary."));
+		dict_show_msgbox(dd, GTK_MESSAGE_ERROR, _("You have chosen an invalid dictionary."));
 		g_free(dictionary);
 		gtk_notebook_set_current_page(
 			GTK_NOTEBOOK(g_object_get_data(G_OBJECT(dlg), "notebook")), NOTEBOOK_PAGE_DICTD);
 		gtk_widget_grab_focus(GTK_WIDGET(g_object_get_data(G_OBJECT(dlg), "dict_combo")));
 		return;
 	}
-	search_url = g_strdup(gtk_entry_get_text(
-			GTK_ENTRY(g_object_get_data(G_OBJECT(dlg), "web_entry"))));
-	if (! NZV(search_url) || search_url[0] == '-')
-	{
-		xfce_err(_("You must set a valid search URL."));
-		g_free(search_url);
-		gtk_notebook_set_current_page(
-			GTK_NOTEBOOK(g_object_get_data(G_OBJECT(dlg), "notebook")), NOTEBOOK_PAGE_WEB);
-		gtk_widget_grab_focus(GTK_WIDGET(g_object_get_data(G_OBJECT(dlg), "web_entry")));
-		return;
-	}
 
 	/* MODE DICT */
 	dd->port = gtk_spin_button_get_value_as_int(
@@ -130,7 +119,9 @@ void dict_prefs_dialog_response(GtkWidget *dlg, gint response, DictData *dd)
 
 	/* MODE WEB */
 	g_free(dd->web_url);
-	dd->web_url = search_url;
+	dd->web_url = g_strdup(gtk_entry_get_text(
+			GTK_ENTRY(g_object_get_data(G_OBJECT(dlg), "web_entry"))));
+	gtk_widget_set_sensitive(dd->radio_button_web, NZV(dd->web_url));
 
 	/* MODE SPELL */
 	dictionary = gtk_combo_box_get_active_text(
@@ -153,8 +144,10 @@ void dict_prefs_dialog_response(GtkWidget *dlg, gint response, DictData *dd)
 		dd->panel_entry_size = gtk_spin_button_get_value_as_int(
 					GTK_SPIN_BUTTON(g_object_get_data(G_OBJECT(dlg), "panel_entry_size_spinner")));
 	}
-	g_object_set(G_OBJECT(dd->link_tag), "foreground-gdk", dd->link_color, NULL);
-	g_object_set(G_OBJECT(dd->phon_tag), "foreground-gdk", dd->phon_color, NULL);
+	g_object_set(G_OBJECT(dd->link_tag), "foreground-gdk", dd->color_link, NULL);
+	g_object_set(G_OBJECT(dd->phon_tag), "foreground-gdk", dd->color_phonetic, NULL);
+	g_object_set(G_OBJECT(dd->error_tag), "foreground-gdk", dd->color_incorrect, NULL);
+	g_object_set(G_OBJECT(dd->success_tag), "foreground-gdk", dd->color_correct, NULL);
 
 	/* save settings */
 	dict_write_rc_file(dd);
@@ -297,7 +290,8 @@ GtkWidget *dict_prefs_dialog_show(GtkWidget *parent, DictData *dd)
 	 */
 #define PAGE_GENERAL /* only for navigation in Geany's symbol list ;-) */
 	{
-		GtkWidget *radio_button, *label, *table, *color_link, *color_phon;
+		GtkWidget *radio_button, *label, *table, *label4;
+		GtkWidget *color_link, *color_phon, *color_success, *color_error;
 		GSList *search_method;
 
 		notebook_vbox = gtk_vbox_new(FALSE, 2);
@@ -356,14 +350,20 @@ GtkWidget *dict_prefs_dialog_show(GtkWidget *parent, DictData *dd)
 		gtk_widget_show(label);
 		gtk_box_pack_start(GTK_BOX(inner_vbox), label, FALSE, FALSE, 5);
 
-		label1 = gtk_label_new(_("Link Color:"));
-		label2 = gtk_label_new(_("Phonetic Color:"));
-		color_link = gtk_color_button_new_with_color(dd->link_color);
-		color_phon = gtk_color_button_new_with_color(dd->phon_color);
-		g_signal_connect(color_link, "color-set", G_CALLBACK(color_set_cb), dd->link_color);
-		g_signal_connect(color_phon, "color-set", G_CALLBACK(color_set_cb), dd->phon_color);
+		label1 = gtk_label_new(_("Links:"));
+		label2 = gtk_label_new(_("Phonetics:"));
+		label3 = gtk_label_new(_("Spelled correctly:"));
+		label4 = gtk_label_new(_("Spelled incorrectly:"));
+		color_link = gtk_color_button_new_with_color(dd->color_link);
+		color_phon = gtk_color_button_new_with_color(dd->color_phonetic);
+		color_error = gtk_color_button_new_with_color(dd->color_incorrect);
+		color_success = gtk_color_button_new_with_color(dd->color_correct);
+		g_signal_connect(color_link, "color-set", G_CALLBACK(color_set_cb), dd->color_link);
+		g_signal_connect(color_phon, "color-set", G_CALLBACK(color_set_cb), dd->color_phonetic);
+		g_signal_connect(color_error, "color-set", G_CALLBACK(color_set_cb), dd->color_incorrect);
+		g_signal_connect(color_success, "color-set", G_CALLBACK(color_set_cb), dd->color_correct);
 
-		table = gtk_table_new(2, 2, FALSE);
+		table = gtk_table_new(2, 4, FALSE);
 		gtk_widget_show(table);
 		gtk_table_set_row_spacings(GTK_TABLE(table), 5);
 		gtk_table_set_col_spacings(GTK_TABLE(table), 5);
@@ -386,6 +386,24 @@ GtkWidget *dict_prefs_dialog_show(GtkWidget *parent, DictData *dd)
 						(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
 						(GtkAttachOptions) (0), 5, 5);
 
+		gtk_table_attach(GTK_TABLE(table), label3, 2, 3, 0, 1,
+						(GtkAttachOptions) (GTK_FILL),
+						(GtkAttachOptions) (0), 5, 5);
+		gtk_misc_set_alignment(GTK_MISC(label3), 1, 0);
+
+		gtk_table_attach(GTK_TABLE(table), color_success, 3, 4, 0, 1,
+						(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+						(GtkAttachOptions) (0), 5, 5);
+
+		gtk_table_attach(GTK_TABLE(table), label4, 2, 3, 1, 2,
+						(GtkAttachOptions) (GTK_FILL),
+						(GtkAttachOptions) (0), 5, 0);
+		gtk_misc_set_alignment(GTK_MISC(label4), 1, 0);
+
+		gtk_table_attach(GTK_TABLE(table), color_error, 3, 4, 1, 2,
+						(GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
+						(GtkAttachOptions) (0), 5, 5);
+
 		gtk_widget_show_all(table);
 		gtk_box_pack_start(GTK_BOX(inner_vbox), table, FALSE, FALSE, 0);
 
@@ -600,7 +618,7 @@ GtkWidget *dict_prefs_dialog_show(GtkWidget *parent, DictData *dd)
 
 		g_object_set_data(G_OBJECT(dialog), "web_entry", web_entry);
 
-		label1 = xfd_wrap_label_new(_("Enter an URL to a web site which offer translation or dictionary services. Use {word} as placeholder for the searched word."));
+		label1 = xfd_wrap_label_new(_("Enter the URL of a web site which offers translation or dictionary services. Use {word} as placeholder for the searched word."));
 		gtk_misc_set_alignment(GTK_MISC(label1), 0, 0);
 		gtk_widget_show(label1);
 		gtk_box_pack_start(GTK_BOX(inner_vbox), label1, FALSE, FALSE, 0);
