@@ -1,6 +1,6 @@
 /*  $Id$
  *
- *  Copyright 2006-2008 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
+ *  Copyright 2006-2009 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #define SPELL_H 1
 
 
-void dict_spell_start_query(DictData *dd, const gchar *word);
+void dict_spell_start_query(DictData *dd, const gchar *word, gboolean quiet);
 
 void dict_spell_get_dictionaries(DictData *dd, GtkWidget *spell_combo);
 
